"""A helper module to create fun, memorable names for experiments, datasets or anything"""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/project/naming.ipynb.

# %% auto 0
__all__ = ['MemorableNames']

# %% ../../nbs/project/naming.ipynb 2
import random

# %% ../../nbs/project/naming.ipynb 3
class MemorableNames:
    def __init__(self):
        # List of adjectives (similar to what Docker uses)
        self.adjectives = [
            "admiring", "adoring", "affectionate", "agitated", "amazing",
            "angry", "awesome", "blissful", "bold", "boring", "brave", "busy",
            "charming", "clever", "cool", "compassionate", "competent", "condescending",
            "confident", "cranky", "crazy", "dazzling", "determined", "distracted",
            "dreamy", "eager", "ecstatic", "elastic", "elated", "elegant", "eloquent",
            "epic", "fervent", "festive", "flamboyant", "focused", "friendly",
            "frosty", "gallant", "gifted", "goofy", "gracious", "happy", "hardcore",
            "heuristic", "hopeful", "hungry", "infallible", "inspiring", "jolly",
            "jovial", "keen", "kind", "laughing", "loving", "lucid", "magical",
            "mystifying", "modest", "musing", "naughty", "nervous", "nifty", "nostalgic",
            "objective", "optimistic", "peaceful", "pedantic", "pensive", "practical",
            "priceless", "quirky", "quizzical", "relaxed", "reverent", "romantic",
            "sad", "serene", "sharp", "silly", "sleepy", "stoic", "stupefied",
            "suspicious", "sweet", "tender", "thirsty", "trusting", "upbeat", "vibrant",
            "vigilant", "vigorous", "wizardly", "wonderful", "xenodochial", "youthful",
            "zealous", "zen"
        ]
        
        # List of influential computer scientists and tech entrepreneurs
        self.scientists = [
            "turing", "hopper", "knuth", "torvalds", "ritchie", "thompson",
            "dijkstra", "kay", "wozniak", "gates", "jobs", "musk", "bezos",
            "lovelace", "berners_lee", "cerf", "gosling", "kernighan", "lamport",
            "mccarthy", "minsky", "rossum", "backus", "engelbart", "hamilton",
            "chomsky", "shannon", "zuckerberg", "page", "brin", "matsumoto",
            "stallman", "stroustrup", "cook", "neumann", "babbage", "tanenbaum",
            "rivest", "shamir", "adleman", "carmack", "andreessen", "ullman",
            "postel", "huffman", "boole", "curry", "liskov", "wing", "goldwasser",
            "hoare", "milner", "perlis", "sutherland", "tarjan", "valiant",
            "yao", "hopcroft", "naur", "wilkes", "codd", "diffie", "hellman",
            "pearl", "thiel", "narayen", "nadella", "pichai", "dorsey"
        ]
        
        self.used_names = set()
    
    def generate_name(self):
        """Generate a single experiment name."""
        adjective = random.choice(self.adjectives)
        scientist = random.choice(self.scientists)
        return f"{adjective}_{scientist}"
    
    def generate_unique_name(self):
        """Generate a unique experiment name."""
        attempts = 0
        max_attempts = 100  # Prevent infinite loops
        
        while attempts < max_attempts:
            name = self.generate_name()
            if name not in self.used_names:
                self.used_names.add(name)
                return name
            attempts += 1
            
        # If we exhaust our combinations, add a random suffix
        base_name = self.generate_name()
        unique_name = f"{base_name}_{random.randint(1000, 9999)}"
        self.used_names.add(unique_name)
        return unique_name
    
    def generate_unique_names(self, count):
        """Generate multiple unique experiment names."""
        return [self.generate_unique_name() for _ in range(count)]
